@@ -29,10 +29,9 @@ from djangosanetesting.selenium.driver import selenium
 from djangosanetesting.utils import (
     get_live_server_path, test_database_exists,
     DEFAULT_LIVE_SERVER_ADDRESS, DEFAULT_LIVE_SERVER_PORT,
-    selenium_patched_open
 )
 
-__all__ = ("CherryPyLiveServerPlugin", "DjangoLiveServerPlugin", "DjangoPlugin", "SeleniumPlugin", "SaneTestSelectionPlugin")
+__all__ = ("CherryPyLiveServerPlugin", "DjangoLiveServerPlugin", "DjangoPlugin", "SeleniumPlugin", "SaneTestSelectionPlugin", "ResultPlugin")
 
 def flush_cache(test_case=None):
     from django.contrib.contenttypes.models import ContentType
@@ -60,11 +59,7 @@ def enable_test(test_case, plugin_attribute):
     if not getattr(test_case, plugin_attribute, False):
         setattr(test_case, plugin_attribute, True)
 
-def flush_database(test_case, database=None):
-    if database is None:
-        from django.db import DEFAULT_DB_ALIAS
-        database = DEFAULT_DB_ALIAS
-
+def flush_database(test_case, database=DEFAULT_DB_ALIAS):
     call_command('flush', verbosity=0, interactive=False, database=database)
 
 #####
@@ -328,14 +323,15 @@ class DjangoPlugin(Plugin):
 
 
     def begin(self):
-        """
-        Before running database, initialize database et al, so noone will complain
-        """
         from django.test.utils import setup_test_environment
         setup_test_environment()
 
-        #FIXME: This should be perhaps moved to startTest and be lazy
-        # for tests that do not need test database at all
+    def prepareTestRunner(self, runner):
+        """
+        Before running tests, initialize database et al, so noone will complain
+        """
+        # FIXME: this should be lazy for tests that do not need test
+        # database at all
         from django.db import connection
         from django.conf import settings
         self.old_name = settings.DATABASE_NAME
@@ -360,7 +356,7 @@ class DjangoPlugin(Plugin):
 
         self.need_flush = False
     
-    def finalize(self, *args, **kwargs):
+    def finalize(self, result):
         """
         At the end, tear down our testbed
         """
@@ -463,16 +459,16 @@ class DjangoPlugin(Plugin):
             for db in databases:
                 call_command('loaddata', *test_case.fixtures, **{'verbosity': 0, 'commit' : commit, 'database' : db})
 
- 
+
     def stopTest(self, test):
         """
         After test is run, clear urlconf and caches
         """
         from django.db import transaction
         from django.conf import settings
-        
+
         test_case = get_test_case_class(test)
-        
+
         if (hasattr(test_case, "database_single_transaction") and test_case.database_single_transaction is True):
             transaction.rollback()
             transaction.leave_transaction_management()
@@ -481,7 +477,7 @@ class DjangoPlugin(Plugin):
             settings.ROOT_URLCONF = test_case._old_root_urlconf
             clear_url_caches()
         flush_cache(test_case)
-        
+
 class DjangoTranslationPlugin(Plugin):
     """
     For testcases with selenium_start set to True, connect to Selenium RC.
@@ -547,7 +543,6 @@ class SeleniumPlugin(Plugin):
                   )
             try:
                 sel.start()
-                sel.open = selenium_patched_open(sel, sel.open)
                 test_case.selenium_started = True
             except Exception, err:
                 # we must catch it all as there is untyped socket exception on Windows :-]]]
@@ -609,6 +604,31 @@ class SaneTestSelectionPlugin(Plugin):
     def startTest(self, test):
         test_case = get_test_case_class(test)
         if getattr(test_case, "test_type", "unit") not in self.enabled_tests:
-            self.skipped = True
+            test_case.skipped = True
             #raise SkipTest(u"Test type %s not enabled" % getattr(test_case, "test_type", "unit"))
 
+##########
+### Result plugin is used when using Django test runner
+### Taken from django-nose project.
+### (C) Jeff Balogh and contributors, released under BSD license.
+##########
+
+class ResultPlugin(Plugin):
+    """
+    Captures the TestResult object for later inspection.
+
+    nose doesn't return the full test result object from any of its runner
+    methods.  Pass an instance of this plugin to the TestProgram and use
+    ``result`` after running the tests to get the TestResult object.
+    """
+
+    name = "djangoresult"
+    activation_parameter = '--with-djangoresult'
+    enabled = True
+
+    def configure(self, options, config):
+        Plugin.configure(self, options, config)
+
+    def finalize(self, result):
+        self.result = result
+
