@@ -3,7 +3,7 @@
 from paver.easy import *
 from paver.setuputils import setup
 
-VERSION = '0.5.9'
+VERSION = '0.5.11'
 name = 'djangosanetesting'
 
 setup(
@@ -24,11 +24,9 @@ Thus, there is a way to start HTTP server for non-WSGI testing - like using Sele
 
 Selenium has also been made super easy - just start --with-selenium, inherit from SeleniumTestCase and use self.selenium.
 
-Package is documented - see docs/ or http://getthedocs.org/Almad/djangosanetesting.
+Package is documented - see docs/ or http://readthedocs.org/projects/Almad/django-sane-testing/docs/index.html .
 ''',
     packages = ['djangosanetesting', 'djangosanetesting.selenium'],
-    scripts = [],
-    data_files = [('.', './paver-minilib.zip'),],
     requires = ['Django (>=1.1)', 'nose (>=0.10)'],
     classifiers=[
         "Development Status :: 4 - Beta",
@@ -47,7 +45,8 @@ Package is documented - see docs/ or http://getthedocs.org/Almad/djangosanetesti
             'django = %s.noseplugins:DjangoPlugin' % name,
             'selenium = %s.noseplugins:SeleniumPlugin' % name,
             'sanetestselection = %s.noseplugins:SaneTestSelectionPlugin' % name,
-            'djangotranslations = %s.noseplugins:DjangoTranslationPlugin' % name, 
+            'djangotranslations = %s.noseplugins:DjangoTranslationPlugin' % name,
+	    'djangoresultplugin = %s.noseplugins:ResultPlugin' % name,
         ]
     }
 )
@@ -66,3 +65,30 @@ options(
     ),
 )
 
+@task
+@consume_args
+def unit(args, nose_run_kwargs=None):
+    """ Run unittests """
+    import os, sys
+    from os.path import join, dirname, abspath
+    
+    test_project_module = "testproject"
+    
+    sys.path.insert(0, abspath(join(dirname(__file__), test_project_module)))
+    sys.path.insert(0, abspath(dirname(__file__)))
+    
+    os.environ['DJANGO_SETTINGS_MODULE'] = "%s.settings" % test_project_module
+    
+    import nose
+
+    os.chdir(test_project_module)
+
+    argv = ["--with-django", "--with-cherrypyliveserver", "--with-selenium"] + args
+
+    nose_run_kwargs = nose_run_kwargs or {}
+
+    nose.run_exit(
+        argv = ["nosetests"] + argv,
+        defaultTest = test_project_module,
+        **nose_run_kwargs
+    )
